
.. _install_guid:

==========================
Installing `SOMA_Pipeline`
==========================

This tutorial will walk you through the process of intalling SOMA...

  * :ref:`Install an official release <install_release>`. This
    is the best approach for users who want a stable version.

  * :ref:`Install the latest development version
    <install_development>`. This is best for users who want to contribute
    to the project.




.. _install_release:

Installing a stable version
==============================





.. _install_development:

Installing the current version
===============================






